@@ -34,17 +34,32 @@ github_package_info <- function(repo, token = NULL){
   stats::setNames(out, tolower(names(out)))
 }
 
-github_install <- function(repo, username, ref, args = NULL, upgrade_dependencies = FALSE, auth_token = github_token(), ...){
+github_install <- function(repo, username, ref, args = NULL, upgrade = FALSE, auth_token = github_token(), ...){
   #get args
   all_args <- list(...)
-  all_args$upgrade_dependencies <- upgrade_dependencies
+  all_args$upgrade <- upgrade
   all_args$auth_token <- auth_token
   all_args$repo <- url_path(username, repo)
   all_args$ref <- ref
 
-  # Sets 'chmod g+xs' to make writable for other users in the group
-  gittmpdir <- tempfile("githubdir")
+  # final app location
+  gitpath <- github_userlib(username, repo)
+
+  # temporary location
+  gittmpdir <- paste0(gitpath, "_00TMP")
+  if(file.exists(gittmpdir)){
+    info <- file.info(gittmpdir)
+    time_limit <- config("timelimit.webhook")
+    if(difftime(Sys.time(), info$mtime, units = 'sec') > time_limit){
+      unlink(gittmpdir, recursive = TRUE)
+    } else {
+      stop("Package is already being installed: ", gittmpdir)
+    }
+  }
   stopifnot(dir.create(gittmpdir))
+  on.exit(unlink(gittmpdir, recursive = TRUE))
+
+  # Sets 'chmod g+xs' to make writable for other users in the group
   Sys.chmod(gittmpdir, "2755")
   all_args$lib <- gittmpdir
   all_args$force <- TRUE
@@ -64,13 +79,10 @@ github_install <- function(repo, username, ref, args = NULL, upgrade_dependencie
   #The index.html for vignettes is useless due to hardcoded hyperlinks
   unlink(file.path(gittmpdir, package, "doc", "index.html"))
 
-  # final app location
-  gitpath <- github_userlib(username, repo)
-
   #move to permanent location
   if(success){
     unlink(gitpath, recursive = TRUE)
-    stopifnot(dir.move(gittmpdir, gitpath))
+    stopifnot(file.rename(gittmpdir, gitpath))
   }
 
   #return success and output
